# #
# Software subject to following license(s):
#   Apache 2 License (http://www.opensource.org/licenses/apache2.0)
#   Copyright (c) Responsible Organization
#

# #
# Current developer(s):
#   Tim Bell <tim.bell@cern.ch>
#

# 
declaration template components/hostsfile/schema;

include 'quattor/schema';

type hostsfile_entry = {
    @{ The IP address of the host. }
    "ipaddr" : type_ip
    @{ A string value of aliases. Multiple aliases should be whitespace separated.}
    "aliases" ? string_trimmed
    @{ A comment to append to the line within /etc/hosts. }
    "comment" ? string_trimmed
};

@documentation{
    Example - configuration defined like this:

      include 'software/components/hostsfile';
      "/software/components/hostsfile/active" = true;
      "/software/components/hostsfile/file" = "/etc/hosts.local";
      "/software/components/hostsfile/entries" = dict (
        "tsmstor601.cern.ch", dict(
            "ipaddr", "192.168.1.101",
            "comment", "TSM DB disks"),
        "tsmstor602.cern.ch", dict(
            "ipaddr", "192.168.1.102",
            "comment", "TSM Staging disks"),
        );

    will modify the /etc/hosts.local file from:

      # Do not remove the following line, or various programs
      # that require network functionality will fail.
      127.0.0.1               localhost.localdomain localhost
      137.138.45.75           lxfsec1604.cern.ch

    to:

      # Generated by Quattor component hostsfile
      # Do not remove the following line, or various programs
      # that require network functionality will fail.
      127.0.0.1               localhost.localdomain localhost
      137.138.45.75           lxfsec1604.cern.ch
      192.168.1.101   tsmstor601.cern.ch tsmstor601 # NCM TSM DB disks
      192.168.1.101   tsmstor602.cern.ch tsmstor602 # NCM TSM Staging disks

    The syntax below is also possible:

      "/software/components/hostsfile/entries/tsmstor603" = dict(
          "ipaddr", "192.168.1.103",
          "comment", "TSM more disks"
      );

    or:

      "/software/components/hostsfile/entries/tsmstor603/ipaddr" = "192.168.1.103";
      "/software/components/hostsfile/entries/tsmstor603/comment" = "Testing";
}
type component_hostsfile_type = {
    include structure_component
    @{ The filename to modify, defaults to /etc/hosts. }
    "file" ? string
    @{ A dict, keyed by hostname. }
    "entries" : hostsfile_entry{}
    @{
        A boolean. If false (the default), then pre-existing host lines in the file
        which are not tagged with the "NCM" comment will be preserved.
        If takeover is true,
        then pre-existing entries for hosts will be taken over and declared to be
        under NCM control.
    }
    "takeover" : boolean = false
};

bind "/software/components/hostsfile" = component_hostsfile_type;
